@@ -1,5 +1,5 @@
 """ this is an area for list """
-def print_lol(the_list,level):
+def print_lol(the_list,level=0):
         for each_item in the_list:
                 if isinstance(each_item,list):
                         print_lol(each_item,level+1)
